@@ -1,6 +1,6 @@
 /*
  * Normaliz
- * Copyright (C) 2007-2021  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
+ * Copyright (C) 2007-2022  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -12,7 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * As an exception, when this program is distributed through (i) the App Store
  * by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or (iii) Google Play
@@ -77,6 +77,9 @@ enum Enum {
     MaximalSubspace,
     Equations,
     Congruences,
+    GroebnerBasis,
+    MarkovBasis,
+    Representations,
     END_ENUM_RANGE(LAST_MATRIX),
 
     START_ENUM_RANGE(FIRST_MATRIX_FLOAT),
@@ -93,6 +96,7 @@ enum Enum {
     GeneratorOfInterior,
     CoveringFace,
     AxesScaling,
+    SingleLatticePoint,
     END_ENUM_RANGE(LAST_VECTOR),
 
     // integer valued
@@ -136,6 +140,7 @@ enum Enum {
     ModuleRank,
     Rank,
     EmbeddingDim,
+    CodimSingularLocus,
     END_ENUM_RANGE(LAST_MACHINE_INTEGER),
 
     // boolean valued
@@ -144,6 +149,8 @@ enum Enum {
     IsDeg1ExtremeRays,
     IsDeg1HilbertBasis,
     IsIntegrallyClosed,
+    IsSerreR1,
+    IsLatticeIdealToric,
     IsReesPrimary,
     IsInhomogeneous,
     IsGorenstein,
@@ -190,6 +197,8 @@ enum Enum {
     DualFVector,
     Incidence,
     DualIncidence,
+    SingularLocus,
+    //
     Sublattice,
     //
     ClassGroup,
@@ -232,11 +241,18 @@ enum Enum {
     NoSignedDec,
     FixedPrecision,
     DistributedComp,
+    NoPatching,
+    NoCoarseProjection,
+    MaxDegRepresentations,
     //
     Dynamic,
     Static,
     //
     WritePreComp,
+    // Gröbner Basis
+    Lex,
+    RevLex,
+    DegLex,
     //
     END_ENUM_RANGE(LAST_PROPERTY),
     //
@@ -249,6 +265,8 @@ enum Enum {
     FullConeDynamic,
     Generators,
     PullingTriangulationInternal,
+    SingleLatticePointInternal,
+    ConeForMonoid,
     //
     // ONLY FOR E§XTENDED TESTS
     //
@@ -282,7 +300,7 @@ class ConeProperties {
     ConeProperties(const std::bitset<ConeProperty::EnumSize>&);
 
     /* set properties */
-    ConeProperties& set(bool value = true); // set ALL to value;
+    ConeProperties& set(bool value = true);  // set ALL to value;
     ConeProperties& set(ConeProperty::Enum, bool value = true);
     ConeProperties& set(const std::string s, bool value = true);
     ConeProperties& set(ConeProperty::Enum, ConeProperty::Enum);
@@ -290,14 +308,14 @@ class ConeProperties {
     ConeProperties& set(const ConeProperties&);
 
     /* reset (=unset) properties */
-    ConeProperties& reset(); //reset ALL
+    ConeProperties& reset();  // reset ALL
     ConeProperties& reset(ConeProperty::Enum Property);
     ConeProperties& reset(const ConeProperties&);
     ConeProperties& reset_compute_options();
 
     // does not change *this
     ConeProperties intersection_with(const ConeProperties& ConeProps) const;
-    
+
     /* test which/how many properties are set */
     bool test(ConeProperty::Enum Property) const;
     bool any() const;
@@ -317,6 +335,9 @@ class ConeProperties {
 
     void check_conflicting_variants();
     void check_Q_permissible(bool after_implications);
+    void check_monoid_goals() const;
+    void check_lattice_ideal_goals() const;
+    void check_compatibility_with_polynomial_constraints(bool inhomogeneous);
     // void set_default_goals(bool inhomogeneous, bool numberfield);
 
     /* print it in a nice way */
@@ -333,10 +354,10 @@ const std::string& toString(ConeProperty::Enum);
 std::ostream& operator<<(std::ostream&, const ConeProperties&);
 OutputType::Enum output_type(ConeProperty::Enum);
 
-ConeProperties all_options(); // returns cps with the options set
-ConeProperties all_goals(); // returns cps with the options set
-ConeProperties all_full_cone_goals(bool renf); // returns the goals controlling compute_full_cone()
-ConeProperties all_goals_using_grading(bool inhomogeneous); // returns the goals which depend on grading
+ConeProperties all_options();                                // returns cps with the options set
+ConeProperties all_goals();                                  // returns cps with the options set
+ConeProperties all_full_cone_goals(bool renf);               // returns the goals controlling compute_full_cone()
+ConeProperties all_goals_using_grading(bool inhomogeneous);  // returns the goals which depend on grading
 ConeProperties only_homogeneous_props();
 ConeProperties only_inhomogeneous_props();
 ConeProperties treated_as_hom_props();
