@@ -1,6 +1,6 @@
 /*
  * Normaliz
- * Copyright (C) 2007-2021  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
+ * Copyright (C) 2007-2022  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -12,7 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * As an exception, when this program is distributed through (i) the App Store
  * by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or (iii) Google Play
@@ -54,10 +54,9 @@
 
 #include "libnormaliz/my_omp.h"
 
-
 #ifdef USE_MPIR
 #include <mpirxx.h>
-#else  // otherwise use GMP 
+#else  // otherwise use GMP
 #include <gmpxx.h>
 #endif
 
@@ -69,16 +68,16 @@
 #ifdef ENFNORMALIZ
 #include <e-antic/renfxx.h>
 namespace libnormaliz {
-using eantic::renf_elem_class;
 using eantic::renf_class;
+using eantic::renf_elem_class;
 typedef boost::intrusive_ptr<const renf_class> renf_class_shared;
-}
+}  // namespace libnormaliz
 #else
 namespace libnormaliz {
 typedef long renf_elem_class;
-struct renf_class{};
+struct renf_class {};
 typedef renf_class* renf_class_shared;
-}
+}  // namespace libnormaliz
 #endif
 
 namespace libnormaliz {
@@ -92,6 +91,7 @@ const nmz_float nmz_epsilon = 1.0e-12;
 typedef unsigned int key_t;
 
 NORMALIZ_DLL_EXPORT extern bool verbose;
+NORMALIZ_DLL_EXPORT extern bool constructor_verbose;
 NORMALIZ_DLL_EXPORT extern size_t GMP_mat, GMP_hyp, GMP_scal_prod;
 NORMALIZ_DLL_EXPORT extern size_t TotDet;
 
@@ -125,13 +125,18 @@ NORMALIZ_DLL_EXPORT extern volatile sig_atomic_t nmz_interrupted;
 // extern bool test_arithmetic_overflow;
 // extern long overflow_test_modulus;
 
-NORMALIZ_DLL_EXPORT extern const long default_thread_limit;
-NORMALIZ_DLL_EXPORT extern long thread_limit;
+NORMALIZ_DLL_EXPORT extern const int default_thread_limit;
+NORMALIZ_DLL_EXPORT extern int thread_limit;
 NORMALIZ_DLL_EXPORT extern bool parallelization_set;
-long set_thread_limit(long t);
+int set_thread_limit(int t);
+
+// debugging helpers
+NORMALIZ_DLL_EXPORT extern long cone_recursion_level;
+NORMALIZ_DLL_EXPORT extern long full_cone_recursion_level;
 
 /* set the verbose default value */
 bool setVerboseDefault(bool v);
+void suppressNextConstructorVerbose();
 /* methods to set and use the output streams */
 void setVerboseOutput(std::ostream&);
 void setErrorOutput(std::ostream&);
@@ -143,6 +148,8 @@ void interrupt_signal_handler(int signal);
 
 void StartTime();
 void MeasureTime(bool verbose, const std::string& step);
+void StartGlobalTime();
+void MeasureGlobalTime(bool verbose);
 
 } /* end namespace libnormaliz */
 
